pystagram.helpers.errors package — pystagram 0.1 documentation

# pystagram.helpers.errors package

## Submodules

## pystagram.helpers.errors.instagram_api_errors module

exception pystagram.helpers.errors.pystagram_errors.PystagramApiEndpointError

  Bases: `PystagramApiError`

exception pystagram.helpers.errors.pystagram_errors.PystagramApiError

  Bases: `Exception`

exception pystagram.helpers.errors.pystagram_errors.PystagramApiHTTPError(*args, **kwargs)

  Bases: `HTTPError`

exception pystagram.helpers.errors.pystagram_errors.PystagramApiNotSupportedError

  Bases: `PystagramApiError`

exception pystagram.helpers.errors.pystagram_errors.PystagramApiTimeoutError(*args, **kwargs)

  Bases: `Timeout`

## Module contents